==> operation-prime-2.0.0-20140317.101053-26-sources.jar: org/gcube/data/analysis/tabulardata/operation/validation/ColumnTypeCastValidatorFactory.java <==
package org.gcube.data.analysis.tabulardata.operation.validation;

import java.util.ArrayList;
import java.util.List;

import javax.inject.Inject;

import org.gcube.data.analysis.tabulardata.cube.CubeManager;
import org.gcube.data.analysis.tabulardata.cube.data.connection.DatabaseConnectionProvider;
import org.gcube.data.analysis.tabulardata.operation.OperationId;
import org.gcube.data.analysis.tabulardata.operation.factories.types.ColumnValidatorFactory;
import org.gcube.data.analysis.tabulardata.operation.invocation.OperationInvocation;
import org.gcube.data.analysis.tabulardata.operation.parameters.Cardinality;
import org.gcube.data.analysis.tabulardata.operation.parameters.Parameter;
import org.gcube.data.analysis.tabulardata.operation.parameters.leaves.DataTypeParameter;
import org.gcube.data.analysis.tabulardata.operation.worker.Worker;
import org.gcube.data.analysis.tabulardata.operation.worker.exceptions.InvalidInvocationException;

public class ColumnTypeCastValidatorFactory extends ColumnValidatorFactory {
	
	private final static List<Parameter> parameters = new ArrayList<Parameter>();
	
	private static final OperationId OPERATION_ID = new OperationId(5002);
	
	public static final DataTypeParameter TARGET_TYPE_PARAMETER = new DataTypeParameter("targetDataType", "Target type", "The data type on which the cast should be checked", Cardinality.ONE);
	
	static{
		parameters.add(TARGET_TYPE_PARAMETER);
	}

	CubeManager cubeManager;
	
	DatabaseConnectionProvider connectionProvider;

	@Inject
	public ColumnTypeCastValidatorFactory(CubeManager cubeManager,
			DatabaseConnectionProvider connectionProvider) {
		this.cubeManager = cubeManager;
		this.connectionProvider = connectionProvider;
	}

	@Override
	public Worker createWorker(OperationInvocation invocation) throws InvalidInvocationException {
		performBaseChecks(invocation);
		return new ColumnTypeCastValidator(invocation, cubeManager, connectionProvider);
		
	}

	@Override
	protected String getOperationName() {
		return "Column type cast check";
	}

	@Override
	protected String getOperationDescription() {
		return "Check if a column type can be casted to another one";
	}

	@Override
	protected List<Parameter> getParameters() {
		return parameters;
	}

	@Override
	protected OperationId getOperationId() {
		return OPERATION_ID;
	}
	
}

==> operation-prime-2.0.1-20140325.113557-7-sources.jar: org/gcube/data/analysis/tabulardata/operation/validation/ColumnTypeCastValidatorFactory.java <==
package org.gcube.data.analysis.tabulardata.operation.validation;

import java.util.ArrayList;
import java.util.List;

import javax.inject.Inject;

import org.gcube.data.analysis.tabulardata.cube.CubeManager;
import org.gcube.data.analysis.tabulardata.cube.data.connection.DatabaseConnectionProvider;
import org.gcube.data.analysis.tabulardata.operation.OperationId;
import org.gcube.data.analysis.tabulardata.operation.factories.types.ColumnValidatorFactory;
import org.gcube.data.analysis.tabulardata.operation.invocation.OperationInvocation;
import org.gcube.data.analysis.tabulardata.operation.parameters.Cardinality;
import org.gcube.data.analysis.tabulardata.operation.parameters.Parameter;
import org.gcube.data.analysis.tabulardata.operation.parameters.leaves.DataTypeParameter;
import org.gcube.data.analysis.tabulardata.operation.worker.Worker;
import org.gcube.data.analysis.tabulardata.operation.worker.exceptions.InvalidInvocationException;

public class ColumnTypeCastValidatorFactory extends ColumnValidatorFactory {
	
	private final static List<Parameter> parameters = new ArrayList<Parameter>();
	
	private static final OperationId OPERATION_ID = new OperationId(5002);
	
	public static final DataTypeParameter TARGET_TYPE_PARAMETER = new DataTypeParameter("targetDataType", "Target type", "The data type on which the cast should be checked", Cardinality.ONE);
	
	static{
		parameters.add(TARGET_TYPE_PARAMETER);
	}

	CubeManager cubeManager;
	
	DatabaseConnectionProvider connectionProvider;

	@Inject
	public ColumnTypeCastValidatorFactory(CubeManager cubeManager,
			DatabaseConnectionProvider connectionProvider) {
		this.cubeManager = cubeManager;
		this.connectionProvider = connectionProvider;
	}

	@Override
	public Worker createWorker(OperationInvocation invocation) throws InvalidInvocationException {
		performBaseChecks(invocation,cubeManager);
		return new ColumnTypeCastValidator(invocation, cubeManager, connectionProvider);
		
	}

	@Override
	protected String getOperationName() {
		return "Column type cast check";
	}

	@Override
	protected String getOperationDescription() {
		return "Check if a column type can be casted to another one";
	}

	@Override
	protected List<Parameter> getParameters() {
		return parameters;
	}

	@Override
	protected OperationId getOperationId() {
		return OPERATION_ID;
	}
	
}
